@@ -1,115 +1,115 @@
 #### 1- calc functions ####
 
-calcCriteriaGR <- function(contrast,groups,W=NULL,sigma=NULL,breaks,
-                           criterion_d1=FALSE,criterion_entropy=TRUE,criterion_Kalinsky=TRUE,criterion_Laboure=TRUE){
-  
-  #### preparation ####
-  n <- length(contrast) 
-  
-  if(criterion_d1==FALSE && criterion_entropy==FALSE && criterion_Kalinsky == FALSE && criterion_Laboure == FALSE){
-    stop("calcCriteriaGR : all criteria must not be simultaneously FALSE \n")
-  }
-  
-  criteria <- c("d1","entropy","Kalinsky","Laboure")[c(criterion_d1,criterion_entropy,criterion_Kalinsky,criterion_Laboure)]
-  
-  df.criterion <- data.frame(matrix(NA,ncol=1+length(criteria),nrow=1))
-  names(df.criterion) <- c("sigma",criteria)
-  if(!is.null(sigma)){df.criterion$sigma <- sigma}
-  
-  #### tests ####
-  if(length(groups)!=n){
-    stop("calcCriteriaGR : \'groups\' must have same length as \'contrast\' \n",       
-         "length(contrast) : ",length(contrast),"\n",
-         "length(groups) : ",length(groups),"\n",)
-  }
-  
-  if(!is.logical(groups)){
-    stop("calcCriteriaGR :  wrong specification of \'groups\' \n",
-         "groups must be a logical vector \n",
-         "is(groups) : ",paste(is(groups),collapse=" "),"\n")
-  }
-  indexT <- which(groups==TRUE)
-  n.T <- length(indexT)
-  indexF <- which(groups==FALSE)
-  n.F <- length(indexF)
-  
-  if(length(indexT)<2 || length(indexF)<2){
-    stop("calcCriteriaGR :  too small groups \n",
-         "sum(groups==TRUE) : ",sum(groups==TRUE),"\n",
-         "sum(groups==FALSE) : ",sum(groups==FALSE),"\n")
-    
-    return(NULL)
-  }
-  
-  #### criterion sur la frontiere ####
-  if(criterion_d1==TRUE){
-    
-    if(is.null(W)){
-      stop("calcCriteriaGR : \'W\' must not be NULL \n")
-    }
-    
-    if(any(dim(W)!=c(n,n))){
-      stop("calcCriteriaGR : wrong dimension of \'W\' \n",
-           "required dimension : ",n," ; ",n,"\n",
-           "dim(W) :",paste(dim(W),collapse=" "),"\n")
-    }
-    
-    
-    # identification de la frontiere
-    nb.voisT <- Matrix::rowSums(W[indexT,indexF]>0)
-    index.frontiereT <- indexT[which(nb.voisT>0)]
-    n.frontiere <- length(index.frontiereT)
-    
-    # iteration sur les points de  la frontiere
-    df.criterion$d1 <- 0 
-    
-    for(iter_frontiere in 1:n.frontiere){
-      indexiter_frontiere <- index.frontiereT[iter_frontiere]
-      indexiter_voisF <- indexF[which(W[indexiter_frontiere,indexF]>0) ]
-      indexiter_voisT <- indexT[which(W[indexiter_frontiere,indexT]>0) ]
-      
-      gradF <- contrast[indexiter_frontiere]-mean(contrast[indexiter_voisF])
-      gradT <- contrast[indexiter_frontiere]-mean(contrast[indexiter_voisT])
-      df.criterion$d1 <- df.criterion$d1 + (abs(gradF) - abs(gradT))    
-    }
-    df.criterion$d1 <- df.criterion$d1/n.frontiere
-    
-  }
-  
-  #### criterion sur l'entropy ####
-  if(criterion_entropy==TRUE){
-    RF <- hist(contrast[indexF],breaks=breaks,plot=FALSE)$counts
-    RT <- hist(contrast[indexT],breaks=breaks,plot=FALSE)$counts
-    
-    RF <- RF[RF>0]
-    RT <- RT[RT>0]
-    
-    df.criterion$entropy <- -mean(RF*log(RF)) - mean(RT*log(RT)) + log(length(indexF)*length(indexT))
-    #df.criterion$entropy <- sum(contrast_entropy[indexT]*log(contrast_entropy[indexT])) + sum( (1-contrast_entropy)[indexF]*log( (1-contrast_entropy)[indexF]))
-  }
-  
-  #### criterion sur la region ####
-  if(criterion_Kalinsky==TRUE || criterion_Laboure==TRUE){
-    moyT <- mean(contrast[indexT])
-    moyF <- mean(contrast[indexF])
-    WT <- sum((contrast[indexT]-moyT)^2)
-    WF <- sum((contrast[indexF]-moyF)^2)
-  }
-  
-  if(criterion_Kalinsky==TRUE){
-    moy <- mean(contrast)
-    
-    B <- (moy-moyT)^2+(moy-moyF)^2 # ddf(B) = 2-1 = 1
-    W <- (WT + WF)/(n.T+n.F-1) # ddf(W) = n-1
-    df.criterion$Kalinsky <- B / W
-  }
-  
-  if(criterion_Laboure==TRUE){
-    df.criterion$Laboure <- 1/sqrt(WT + WF)
-  }
-  
-  return(df.criterion)
-}
+# calcCriteriaGR <- function(contrast,groups,W=NULL,sigma=NULL,breaks,
+#                            criterion_d1=FALSE,criterion_entropy=TRUE,criterion_Kalinsky=TRUE,criterion_Laboure=TRUE){
+#   
+#   #### preparation ####
+#   n <- length(contrast) 
+#   
+#   if(criterion_d1==FALSE && criterion_entropy==FALSE && criterion_Kalinsky == FALSE && criterion_Laboure == FALSE){
+#     stop("calcCriteriaGR : all criteria must not be simultaneously FALSE \n")
+#   }
+#   
+#   criteria <- c("d1","entropy","Kalinsky","Laboure")[c(criterion_d1,criterion_entropy,criterion_Kalinsky,criterion_Laboure)]
+#   
+#   df.criterion <- data.frame(matrix(NA,ncol=1+length(criteria),nrow=1))
+#   names(df.criterion) <- c("sigma",criteria)
+#   if(!is.null(sigma)){df.criterion$sigma <- sigma}
+#   
+#   #### tests ####
+#   if(length(groups)!=n){
+#     stop("calcCriteriaGR : \'groups\' must have same length as \'contrast\' \n",       
+#          "length(contrast) : ",length(contrast),"\n",
+#          "length(groups) : ",length(groups),"\n",)
+#   }
+#   
+#   if(!is.logical(groups)){
+#     stop("calcCriteriaGR :  wrong specification of \'groups\' \n",
+#          "groups must be a logical vector \n",
+#          "is(groups) : ",paste(is(groups),collapse=" "),"\n")
+#   }
+#   indexT <- which(groups==TRUE)
+#   n.T <- length(indexT)
+#   indexF <- which(groups==FALSE)
+#   n.F <- length(indexF)
+#   
+#   if(length(indexT)<2 || length(indexF)<2){
+#     stop("calcCriteriaGR :  too small groups \n",
+#          "sum(groups==TRUE) : ",sum(groups==TRUE),"\n",
+#          "sum(groups==FALSE) : ",sum(groups==FALSE),"\n")
+#     
+#     return(NULL)
+#   }
+#   
+#   #### criterion sur la frontiere ####
+#   if(criterion_d1==TRUE){
+#     
+#     if(is.null(W)){
+#       stop("calcCriteriaGR : \'W\' must not be NULL \n")
+#     }
+#     
+#     if(any(dim(W)!=c(n,n))){
+#       stop("calcCriteriaGR : wrong dimension of \'W\' \n",
+#            "required dimension : ",n," ; ",n,"\n",
+#            "dim(W) :",paste(dim(W),collapse=" "),"\n")
+#     }
+#     
+#     
+#     # identification de la frontiere
+#     nb.voisT <- Matrix::rowSums(W[indexT,indexF]>0)
+#     index.frontiereT <- indexT[which(nb.voisT>0)]
+#     n.frontiere <- length(index.frontiereT)
+#     
+#     # iteration sur les points de  la frontiere
+#     df.criterion$d1 <- 0 
+#     
+#     for(iter_frontiere in 1:n.frontiere){
+#       indexiter_frontiere <- index.frontiereT[iter_frontiere]
+#       indexiter_voisF <- indexF[which(W[indexiter_frontiere,indexF]>0) ]
+#       indexiter_voisT <- indexT[which(W[indexiter_frontiere,indexT]>0) ]
+#       
+#       gradF <- contrast[indexiter_frontiere]-mean(contrast[indexiter_voisF])
+#       gradT <- contrast[indexiter_frontiere]-mean(contrast[indexiter_voisT])
+#       df.criterion$d1 <- df.criterion$d1 + (abs(gradF) - abs(gradT))    
+#     }
+#     df.criterion$d1 <- df.criterion$d1/n.frontiere
+#     
+#   }
+#   
+#   #### criterion sur l'entropy ####
+#   if(criterion_entropy==TRUE){
+#     RF <- hist(contrast[indexF],breaks=breaks,plot=FALSE)$counts
+#     RT <- hist(contrast[indexT],breaks=breaks,plot=FALSE)$counts
+#     
+#     RF <- RF[RF>0]
+#     RT <- RT[RT>0]
+#     
+#     df.criterion$entropy <- -mean(RF*log(RF)) - mean(RT*log(RT)) + log(length(indexF)*length(indexT))
+#     #df.criterion$entropy <- sum(contrast_entropy[indexT]*log(contrast_entropy[indexT])) + sum( (1-contrast_entropy)[indexF]*log( (1-contrast_entropy)[indexF]))
+#   }
+#   
+#   #### criterion sur la region ####
+#   if(criterion_Kalinsky==TRUE || criterion_Laboure==TRUE){
+#     moyT <- mean(contrast[indexT])
+#     moyF <- mean(contrast[indexF])
+#     WT <- sum((contrast[indexT]-moyT)^2)
+#     WF <- sum((contrast[indexF]-moyF)^2)
+#   }
+#   
+#   if(criterion_Kalinsky==TRUE){
+#     moy <- mean(contrast)
+#     
+#     B <- (moy-moyT)^2+(moy-moyF)^2 # ddf(B) = 2-1 = 1
+#     W <- (WT + WF)/(n.T+n.F-1) # ddf(W) = n-1
+#     df.criterion$Kalinsky <- B / W
+#   }
+#   
+#   if(criterion_Laboure==TRUE){
+#     df.criterion$Laboure <- 1/sqrt(WT + WF)
+#   }
+#   
+#   return(df.criterion)
+# }
 
 
 
@@ -164,116 +164,116 @@ calcGR <- function(contrast,W,seed,sigma_max,range=c(-Inf,+Inf),range.seed=c(-In
   
 }
 
-calcSigmaGR <- function(contrast,W,seed,sigma,range=c(-Inf,+Inf),range.seed=c(-Inf,+Inf),
-                        breaks=100,scale=FALSE,iter_max=100,sd.robust=FALSE,
-                        criterion_d1=FALSE,criterion_entropy=TRUE,criterion_Kalinsky=TRUE,criterion_Laboure=TRUE,
-                        trace=TRUE,mar=rep(2,4),mgp=c(2,0.75,0),main="",
-                        window=FALSE,filename="calcSigmaGR",width=1000,height=700,path=NULL,unit="px",res=NA){
-  
-  
-  #### initialization ####
-  sigma <- sort(sigma)
-  
-  ## GR
-  n <- length(contrast)
-  
-  res.initGR <- initGR(contrast=contrast,W=W,seed=seed,range=range,range.seed=range.seed,
-                       breaks=breaks,scale=scale,trace=trace,method="calcSigmaGR")
-  
-  contrast <- res.initGR$contrast
-  breaks <- res.initGR$breaks 
-  step <- res.initGR$step 
-  seed.sigma <- res.initGR$seed 
-  
-  # window
-  res.initW <- initWindow(window,filename,path,width,height,unit,res,
-                          n.plot=1,mfrow=c(1,1),xlim=NULL,ylim=NULL,method="calcSigmaGR")
-  scale <- res.initW$scale
-  
-  ## specific criteria
-  n.sigma <- length(sigma)
-  
-  criteria <- c("d1","entropy","Kalinsky","Laboure")[c(criterion_d1,criterion_entropy,criterion_Kalinsky,criterion_Laboure)]
-  n.criteria <- length(criteria)
-  if(n.criteria==0){
-    stop("calcSigmaGR : all criteria must not be simultaneously FALSE \n")
-  }
-  
-  df.criterion <- data.frame(matrix(NA,ncol=1+n.criteria,nrow=n.sigma))
-  names(df.criterion) <- c("sigma",criteria)
-  df.criterion$sigma <- sigma
-  
-  
-  #### loop ####
-  list.GR <- sapply(1:n.criteria,function(x){c(list(),NA)})
-  names(list.GR) <- criteria
-  
-  best <- data.frame(matrix(-Inf,nrow=1,ncol=4))
-  names(best) <- criteria
-  
-  if(trace==TRUE){cat("loop over ",n.sigma," sigma : ",sep="")}
-  
-  for(iter_sigma in 1:n.sigma){
-    if(trace==TRUE){cat("*")}
-    
-    ## GR
-    resGR <- GRalgo(contrast=contrast,W=W,seed=seed,sigma_max=sigma[iter_sigma],range=range,
-                    breaks=breaks,step=step,operator=if(sd.robust){"mad"}else{"sd"},iter_max=iter_max,                    
-                    history_sigma=TRUE,history_step=FALSE,history_front=FALSE)
-    
-    ## Compute criteria
-    df.criterion[iter_sigma,] <- calcCriteriaGR(contrast=contrast,groups=(1:n) %in% resGR$GR,W=W,
-                                                sigma=sigma[iter_sigma],breaks=breaks,
-                                                criterion_d1=criterion_d1,criterion_entropy=criterion_entropy,
-                                                criterion_Kalinsky=criterion_Kalinsky,criterion_Laboure=criterion_Laboure)
-    
-    ## save optimum
-    for(iter_criteria in 1:n.criteria){
-      if(!is.na(df.criterion[iter_sigma,iter_criteria+1]) && df.criterion[iter_sigma,iter_criteria+1]>best[iter_criteria]){
-        list.GR[[iter_criteria]] <- resGR$GR
-        best[iter_criteria] <- df.criterion[iter_sigma,iter_criteria+1]
-      }            
-    }
-    
-    ## update
-    if(length(resGR$GR)>0){seed.sigma <- resGR$GR}    
-    if(length(resGR$GR)==n){break}
-  }
-  if(trace==TRUE){cat("\n")}
-  
-  
-  if(!is.null(plot)){
-    
-    df.criterion_scale <- scale(df.criterion[,-1,drop=F])
-    diff_sigma <- min(diff(sigma))
-    diff_sigmaOpt <- seq(-diff_sigma/10,+diff_sigma/10,length.out=n.criteria)
-    
-    initDisplayWindow(window=window,filename=filename,path=path,width=width,height=height,scale=scale,res=res,
-                      mfrow=c(1,1),bg=par()$bg,pty=par()$pty,mar=mar,mgp=mgp)
-    
-    plot(x=sigma,y=rep(NA,n.sigma),ylim=c(0,0.5)+range(df.criterion_scale,na.rm=T),xlab="sigma",ylab="scaled value",main=main)
-    for(iter_criterion in 1:n.criteria){
-      points(sigma,df.criterion_scale[,iter_criterion],col=rainbow(10)[iter_criterion],
-             type="b",pch=20)
-      
-      diff_opt <- abs(df.criterion[,iter_criterion+1]-as.numeric(best[iter_criterion]))
-      abline(v=sigma[which.min(diff_opt)]+diff_sigmaOpt[iter_criterion],col=rainbow(10)[iter_criterion])
-    }    
-    
-    legend("topright",legend=criteria,col=rainbow(10)[1:n.criteria],pch=20,bty="n")
-    
-    switch(window,
-           eps=dev.off(),
-           svg=dev.off(),
-           png=dev.off()
-    )
-  }
-  
-  return(list(df.criterion=df.criterion,
-              list.GR=list.GR,
-              best=best)
-  )
-}
+# calcSigmaGR <- function(contrast,W,seed,sigma,range=c(-Inf,+Inf),range.seed=c(-Inf,+Inf),
+#                         breaks=100,scale=FALSE,iter_max=100,sd.robust=FALSE,
+#                         criterion_d1=FALSE,criterion_entropy=TRUE,criterion_Kalinsky=TRUE,criterion_Laboure=TRUE,
+#                         trace=TRUE,mar=rep(2,4),mgp=c(2,0.75,0),main="",
+#                         window=FALSE,filename="calcSigmaGR",width=1000,height=700,path=NULL,unit="px",res=NA){
+#   
+#   
+#   #### initialization ####
+#   sigma <- sort(sigma)
+#   
+#   ## GR
+#   n <- length(contrast)
+#   
+#   res.initGR <- initGR(contrast=contrast,W=W,seed=seed,range=range,range.seed=range.seed,
+#                        breaks=breaks,scale=scale,trace=trace,method="calcSigmaGR")
+#   
+#   contrast <- res.initGR$contrast
+#   breaks <- res.initGR$breaks 
+#   step <- res.initGR$step 
+#   seed.sigma <- res.initGR$seed 
+#   
+#   # window
+#   res.initW <- initWindow(window,filename,path,width,height,unit,res,
+#                           n.plot=1,mfrow=c(1,1),xlim=NULL,ylim=NULL,method="calcSigmaGR")
+#   scale <- res.initW$scale
+#   
+#   ## specific criteria
+#   n.sigma <- length(sigma)
+#   
+#   criteria <- c("d1","entropy","Kalinsky","Laboure")[c(criterion_d1,criterion_entropy,criterion_Kalinsky,criterion_Laboure)]
+#   n.criteria <- length(criteria)
+#   if(n.criteria==0){
+#     stop("calcSigmaGR : all criteria must not be simultaneously FALSE \n")
+#   }
+#   
+#   df.criterion <- data.frame(matrix(NA,ncol=1+n.criteria,nrow=n.sigma))
+#   names(df.criterion) <- c("sigma",criteria)
+#   df.criterion$sigma <- sigma
+#   
+#   
+#   #### loop ####
+#   list.GR <- sapply(1:n.criteria,function(x){c(list(),NA)})
+#   names(list.GR) <- criteria
+#   
+#   best <- data.frame(matrix(-Inf,nrow=1,ncol=4))
+#   names(best) <- criteria
+#   
+#   if(trace==TRUE){cat("loop over ",n.sigma," sigma : ",sep="")}
+#   
+#   for(iter_sigma in 1:n.sigma){
+#     if(trace==TRUE){cat("*")}
+#     
+#     ## GR
+#     resGR <- GRalgo(contrast=contrast,W=W,seed=seed,sigma_max=sigma[iter_sigma],range=range,
+#                     breaks=breaks,step=step,operator=if(sd.robust){"mad"}else{"sd"},iter_max=iter_max,                    
+#                     history_sigma=TRUE,history_step=FALSE,history_front=FALSE)
+#     
+#     ## Compute criteria
+#     df.criterion[iter_sigma,] <- calcCriteriaGR(contrast=contrast,groups=(1:n) %in% resGR$GR,W=W,
+#                                                 sigma=sigma[iter_sigma],breaks=breaks,
+#                                                 criterion_d1=criterion_d1,criterion_entropy=criterion_entropy,
+#                                                 criterion_Kalinsky=criterion_Kalinsky,criterion_Laboure=criterion_Laboure)
+#     
+#     ## save optimum
+#     for(iter_criteria in 1:n.criteria){
+#       if(!is.na(df.criterion[iter_sigma,iter_criteria+1]) && df.criterion[iter_sigma,iter_criteria+1]>best[iter_criteria]){
+#         list.GR[[iter_criteria]] <- resGR$GR
+#         best[iter_criteria] <- df.criterion[iter_sigma,iter_criteria+1]
+#       }            
+#     }
+#     
+#     ## update
+#     if(length(resGR$GR)>0){seed.sigma <- resGR$GR}    
+#     if(length(resGR$GR)==n){break}
+#   }
+#   if(trace==TRUE){cat("\n")}
+#   
+#   
+#   if(!is.null(plot)){
+#     
+#     df.criterion_scale <- scale(df.criterion[,-1,drop=F])
+#     diff_sigma <- min(diff(sigma))
+#     diff_sigmaOpt <- seq(-diff_sigma/10,+diff_sigma/10,length.out=n.criteria)
+#     
+#     initDisplayWindow(window=window,filename=filename,path=path,width=width,height=height,scale=scale,res=res,
+#                       mfrow=c(1,1),bg=par()$bg,pty=par()$pty,mar=mar,mgp=mgp)
+#     
+#     plot(x=sigma,y=rep(NA,n.sigma),ylim=c(0,0.5)+range(df.criterion_scale,na.rm=T),xlab="sigma",ylab="scaled value",main=main)
+#     for(iter_criterion in 1:n.criteria){
+#       points(sigma,df.criterion_scale[,iter_criterion],col=rainbow(10)[iter_criterion],
+#              type="b",pch=20)
+#       
+#       diff_opt <- abs(df.criterion[,iter_criterion+1]-as.numeric(best[iter_criterion]))
+#       abline(v=sigma[which.min(diff_opt)]+diff_sigmaOpt[iter_criterion],col=rainbow(10)[iter_criterion])
+#     }    
+#     
+#     legend("topright",legend=criteria,col=rainbow(10)[1:n.criteria],pch=20,bty="n")
+#     
+#     switch(window,
+#            eps=dev.off(),
+#            svg=dev.off(),
+#            png=dev.off()
+#     )
+#   }
+#   
+#   return(list(df.criterion=df.criterion,
+#               list.GR=list.GR,
+#               best=best)
+#   )
+# }
 
 GRalgo <- function(contrast,W,seed,sigma_max,range,breaks,step,operator,iter_max,
                    history_sigma,history_step,history_front){  
